html,body {color:#333;font-family:'Lucida Grande','Lucida Sans Unicode','Verdana',sans-serif;font-size:9pt;}
h1, h2, h3, h4 {font-family:'Andale Mono',monospace;font-size:18pt;text-shadow:1px 1px 1px #333;}
a, a:active, a:link {color:#00008b;text-decoration:none;}

#header {background-color:#111;margin:10px 10px 0 10px;padding:10px;text-align:center;}
#header a, #header a:active, #header a:hover {color:#ccc;}
#content {clear:both;margin:5px 10px 5px 10px;padding:15px 35px 15px 35px;}
#content h1, #content h2 {font-size:12pt;}
#content h3, #content h4 {font-size:10pt;}

.clear {clear:both;}
.rows {padding:5px 0 0 0;}
.rows .header {border-bottom:1px solid #ccc;display:block;float:left;font-weight:bold;padding:0 10px 10px 10px;width:150px;}
.rows .item {border-bottom:1px solid #ccc;display:block;float:left;padding:10px;text-align:left;width:150px;height:20px;}
.info {border-bottom:1px solid #333;font-weight:bold;display:block;float:left;padding:0 10px 0 10px;width:150px;}
