{% extends "layout.html" %}
{% block title %}inetutils PyPI Server{% endblock %}
{% block content %}

{% if eggbaskets %}
<h1>Available EggBaskets</h1>
    <div class="clear"></div>
    {% for e in eggbaskets %}
    <div class="rows">
        <span class="item">
            <a href="{{ url_for('eggbasket', eggbasket=e) }}">{{ e }}</a>
        </span>
    </div>
    <div class="clear"></div>
    {% endfor %}
{% endif %}
{% endblock %}
