{% extends "layout.html" %}
{% block title %}inetutils PyPI - 404 Page not found!{% endblock %}
{% block content %}

<h1>404 - Page not found</h1>
<p>The page you're request could not be found.</p>

{% endblock %}
