<!doctype html>
<html>
    <head>
{% assets "css" %}
        <link href="{{ ASSET_URL }}" rel="stylesheet" type="text/css" />
{% endassets %}
        <link rel="shortcut icon" href="{{ url_for('static', filename='images/favicon.ico') }}" />
        <meta http-equiv="Content-type" content="text/html;charset=UTF-8">
        <script src="http://ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js" type="text/javascript"></script>
        <title>{% block title %}{% endblock %}</title>
    </head>

    <body>
        <div id="header">
            <h1><a href="{{ url_for('index') }}" title="inetutils PyPI">inetutils PyPI</a></h1>
        </div>

        <div id="menu">
        </div>

        <div id="content">
            <h1><a href="{{ url_for('index') }}">Home</a></h1>
{% block content %}{% endblock %}
        </div>

        <div id="footer">
        </div>
    </body>
</html>
