#!/usr/bin/env python
# -*- coding: utf8 -*-

#import inupypi
#import tempfile
#import unittest
#
#from tests.packages import *
#from unipath import Path
#
#
#class Test_Manage(unittest.TestCase):
#    def setUp(self):
#        self.app = inupypi.app.test_client()
#
#    def tearDown(self):
#        pass
#
#    def test_manage_main_page(self):
#        assert self.app.get('/inupypi/manage/').status_code == 200
#        assert 'inetutils PyPI Server' in self.app.get('/inupypi/manage/').data
